# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"get_project_root": "00_core.ipynb",
         "PROJECT_ROOT": "00_core.ipynb",
         "get_project_name": "00_core.ipynb",
         "get_project_metadata": "00_core.ipynb",
         "get_gitignore_list": "00_core.ipynb",
         "in_gitignore": "00_core.ipynb",
         "update_templates": "01_update_project.ipynb"}

modules = ["core.py",
           "update_project.py"]

doc_url = "https://ryanfobel.github.io/kicad_helpers/"

git_url = "https://github.com/ryanfobel/kicad_helpers/tree/main/"

def custom_doc_links(name): return None
